# Backbone-relational

Backbone-relational provides one-to-one, one-to-many and many-to-one relations between models for [Backbone](https://github.com/documentcloud/backbone).

Documentation: http://backbonerelational.org

Backbone-relational is released under the [MIT license](https://github.com/PaulUithol/Backbone-relational/blob/master/LICENSE.txt).
Contributors: https://github.com/PaulUithol/Backbone-relational/contributors
